"""Pad QL System ROMs to 49152 (48KBytes)
(required for sQLux, UQLX does not need padding for shorter ROMS)
"""
import sys
import os

FILE_LENGTH = 49152  # Length of a QL ROM
PAD_BYTE = b'\0'

def main():
    print('Pad a file shorter than 49152 bytes (48K) to exactly 49152 bytes.')
    print('File is padded with bytes with value 0 and written to a new file.')
    filename = input('Name of input file: ')
    if not os.path.exists(filename):
        print(f'{filename} not found. Exiting...')
        sys.exit(1)
    if not os.path.isfile(filename):
        print(f'{filename} is not a file. Exiting')
        sys.exit(2)
    outfile = input ('Name of output file: ')
    if outfile.lower() == filename.lower():
        print('Output file must be different from input file. Exiting...')
        sys.exit(3)
    if os.path.exists(outfile):
        over_ok = input(f'{outfile} exists, okay to overwrite (y/n)? ')
        if over_ok.lower() != 'y':
            print('Exiting...')
            sys.exit(4)
    with open(filename, 'rb') as fp:
        content = fp.read()
    length = len(content)
    print(f'File length is {length} bytes')
    padlen = FILE_LENGTH - length
    padbytes = PAD_BYTE * padlen
    print(f'Inserting {padlen} {int.from_bytes(PAD_BYTE, "little")}-Bytes')
    print(f'Padding {outfile} to {length + padlen} bytes')
    with open(outfile, 'wb') as fp:
        fp.write(content)
        fp.write(padbytes)
    print(f'{outfile} padded to {os.path.getsize(outfile)} bytes')


if __name__ == '__main__':
    main()
